@@ -5,7 +5,7 @@
  *	the time and date facilities of TclX, by Mark Diekhans and Karl
  *	Lehenbauer.
  *
- * Copyright 1991-1995 Karl Lehenbauer and Mark Diekhans.
+ * Copyright (c) 1991-1995 Karl Lehenbauer & Mark Diekhans.
  * Copyright (c) 1995 Sun Microsystems, Inc.
  * Copyright (c) 2004 by Kevin B. Kenny. All rights reserved.
  *
@@ -263,7 +263,7 @@ TclClockInit(
     };
 
     /*
-     * Safe interps get [::clock] as alias to a master, so do not need their
+     * Safe interps get [::clock] as alias to a parent, so do not need their
      * own copies of the support routines.
      */
 
@@ -337,7 +337,7 @@ ClockConvertlocaltoutcObjCmd(
     Tcl_Obj *const *objv)	/* Parameter vector */
 {
     ClockClientData *data = clientData;
-    Tcl_Obj *const *literals = data->literals;
+    Tcl_Obj *const *lit = data->literals;
     Tcl_Obj *secondsObj;
     Tcl_Obj *dict;
     int changeover;
@@ -354,7 +354,7 @@ ClockConvertlocaltoutcObjCmd(
 	return TCL_ERROR;
     }
     dict = objv[1];
-    if (Tcl_DictObjGet(interp, dict, literals[LIT_LOCALSECONDS],
+    if (Tcl_DictObjGet(interp, dict, lit[LIT_LOCALSECONDS],
 	    &secondsObj)!= TCL_OK) {
 	return TCL_ERROR;
     }
@@ -380,7 +380,7 @@ ClockConvertlocaltoutcObjCmd(
 	created = 1;
 	Tcl_IncrRefCount(dict);
     }
-    status = Tcl_DictObjPut(interp, dict, literals[LIT_SECONDS],
+    status = Tcl_DictObjPut(interp, dict, lit[LIT_SECONDS],
 	    Tcl_NewWideIntObj(fields.seconds));
     if (status == TCL_OK) {
 	Tcl_SetObjResult(interp, dict);
@@ -431,7 +431,7 @@ ClockGetdatefieldsObjCmd(
     TclDateFields fields;
     Tcl_Obj *dict;
     ClockClientData *data = clientData;
-    Tcl_Obj *const *literals = data->literals;
+    Tcl_Obj *const *lit = data->literals;
     int changeover;
 
     /*
@@ -453,7 +453,7 @@ ClockGetdatefieldsObjCmd(
      */
 
     if (objv[1]->typePtr == &tclBignumType) {
-	Tcl_SetObjResult(interp, literals[LIT_INTEGER_VALUE_TOO_LARGE]);
+	Tcl_SetObjResult(interp, lit[LIT_INTEGER_VALUE_TOO_LARGE]);
 	return TCL_ERROR;
     }
 
@@ -481,33 +481,33 @@ ClockGetdatefieldsObjCmd(
     GetYearWeekDay(&fields, changeover);
 
     dict = Tcl_NewDictObj();
-    Tcl_DictObjPut(NULL, dict, literals[LIT_LOCALSECONDS],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_LOCALSECONDS],
 	    Tcl_NewWideIntObj(fields.localSeconds));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_SECONDS],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_SECONDS],
 	    Tcl_NewWideIntObj(fields.seconds));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_TZNAME], fields.tzName);
+    Tcl_DictObjPut(NULL, dict, lit[LIT_TZNAME], fields.tzName);
     Tcl_DecrRefCount(fields.tzName);
-    Tcl_DictObjPut(NULL, dict, literals[LIT_TZOFFSET],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_TZOFFSET],
 	    Tcl_NewIntObj(fields.tzOffset));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_JULIANDAY],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_JULIANDAY],
 	    Tcl_NewIntObj(fields.julianDay));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_GREGORIAN],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_GREGORIAN],
 	    Tcl_NewIntObj(fields.gregorian));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_ERA],
-	    literals[fields.era ? LIT_BCE : LIT_CE]);
-    Tcl_DictObjPut(NULL, dict, literals[LIT_YEAR],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_ERA],
+	    lit[fields.era ? LIT_BCE : LIT_CE]);
+    Tcl_DictObjPut(NULL, dict, lit[LIT_YEAR],
 	    Tcl_NewIntObj(fields.year));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_DAYOFYEAR],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_DAYOFYEAR],
 	    Tcl_NewIntObj(fields.dayOfYear));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_MONTH],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_MONTH],
 	    Tcl_NewIntObj(fields.month));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_DAYOFMONTH],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_DAYOFMONTH],
 	    Tcl_NewIntObj(fields.dayOfMonth));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_ISO8601YEAR],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_ISO8601YEAR],
 	    Tcl_NewIntObj(fields.iso8601Year));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_ISO8601WEEK],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_ISO8601WEEK],
 	    Tcl_NewIntObj(fields.iso8601Week));
-    Tcl_DictObjPut(NULL, dict, literals[LIT_DAYOFWEEK],
+    Tcl_DictObjPut(NULL, dict, lit[LIT_DAYOFWEEK],
 	    Tcl_NewIntObj(fields.dayOfWeek));
     Tcl_SetObjResult(interp, dict);
 
@@ -585,7 +585,7 @@ ClockGetjuliandayfromerayearmonthdayObjCmd(
     TclDateFields fields;
     Tcl_Obj *dict;
     ClockClientData *data = clientData;
-    Tcl_Obj *const *literals = data->literals;
+    Tcl_Obj *const *lit = data->literals;
     int changeover;
     int copied = 0;
     int status;
@@ -600,12 +600,12 @@ ClockGetjuliandayfromerayearmonthdayObjCmd(
 	return TCL_ERROR;
     }
     dict = objv[1];
-    if (FetchEraField(interp, dict, literals[LIT_ERA], &era) != TCL_OK
-	    || FetchIntField(interp, dict, literals[LIT_YEAR], &fields.year)
+    if (FetchEraField(interp, dict, lit[LIT_ERA], &era) != TCL_OK
+	    || FetchIntField(interp, dict, lit[LIT_YEAR], &fields.year)
 		!= TCL_OK
-	    || FetchIntField(interp, dict, literals[LIT_MONTH], &fields.month)
+	    || FetchIntField(interp, dict, lit[LIT_MONTH], &fields.month)
 		!= TCL_OK
-	    || FetchIntField(interp, dict, literals[LIT_DAYOFMONTH],
+	    || FetchIntField(interp, dict, lit[LIT_DAYOFMONTH],
 		&fields.dayOfMonth) != TCL_OK
 	    || TclGetIntFromObj(interp, objv[2], &changeover) != TCL_OK) {
 	return TCL_ERROR;
@@ -627,7 +627,7 @@ ClockGetjuliandayfromerayearmonthdayObjCmd(
 	Tcl_IncrRefCount(dict);
 	copied = 1;
     }
-    status = Tcl_DictObjPut(interp, dict, literals[LIT_JULIANDAY],
+    status = Tcl_DictObjPut(interp, dict, lit[LIT_JULIANDAY],
 	    Tcl_NewIntObj(fields.julianDay));
     if (status == TCL_OK) {
 	Tcl_SetObjResult(interp, dict);
@@ -669,7 +669,7 @@ ClockGetjuliandayfromerayearweekdayObjCmd(
     TclDateFields fields;
     Tcl_Obj *dict;
     ClockClientData *data = clientData;
-    Tcl_Obj *const *literals = data->literals;
+    Tcl_Obj *const *lit = data->literals;
     int changeover;
     int copied = 0;
     int status;
@@ -684,12 +684,12 @@ ClockGetjuliandayfromerayearweekdayObjCmd(
 	return TCL_ERROR;
     }
     dict = objv[1];
-    if (FetchEraField(interp, dict, literals[LIT_ERA], &era) != TCL_OK
-	    || FetchIntField(interp, dict, literals[LIT_ISO8601YEAR],
+    if (FetchEraField(interp, dict, lit[LIT_ERA], &era) != TCL_OK
+	    || FetchIntField(interp, dict, lit[LIT_ISO8601YEAR],
 		&fields.iso8601Year) != TCL_OK
-	    || FetchIntField(interp, dict, literals[LIT_ISO8601WEEK],
+	    || FetchIntField(interp, dict, lit[LIT_ISO8601WEEK],
 		&fields.iso8601Week) != TCL_OK
-	    || FetchIntField(interp, dict, literals[LIT_DAYOFWEEK],
+	    || FetchIntField(interp, dict, lit[LIT_DAYOFWEEK],
 		&fields.dayOfWeek) != TCL_OK
 	    || TclGetIntFromObj(interp, objv[2], &changeover) != TCL_OK) {
 	return TCL_ERROR;
@@ -711,7 +711,7 @@ ClockGetjuliandayfromerayearweekdayObjCmd(
 	Tcl_IncrRefCount(dict);
 	copied = 1;
     }
-    status = Tcl_DictObjPut(interp, dict, literals[LIT_JULIANDAY],
+    status = Tcl_DictObjPut(interp, dict, lit[LIT_JULIANDAY],
 	    Tcl_NewIntObj(fields.julianDay));
     if (status == TCL_OK) {
 	Tcl_SetObjResult(interp, dict);
@@ -1052,7 +1052,7 @@ ConvertUTCToLocalUsingC(
     time_t tock;
     struct tm *timeVal;		/* Time after conversion */
     int diff;			/* Time zone diff local-Greenwich */
-    char buffer[8];		/* Buffer for time zone name */
+    char buffer[16];		/* Buffer for time zone name */
 
     /*
      * Use 'localtime' to determine local year, month, day, time of day.
@@ -1513,7 +1513,7 @@ GetJulianDayFromEraYearMonthDay(
      * Try an initial conversion in the Gregorian calendar.
      */
 
-#if 0 /* BUG http://core.tcl.tk/tcl/tktview?name=da340d4f32 */
+#if 0 /* BUG https://core.tcl-lang.org/tcl/tktview?name=da340d4f32 */
     ym1o4 = ym1 / 4;
 #else
     /*
@@ -1652,6 +1652,7 @@ ClockGetenvObjCmd(
 {
     const char *varName;
     const char *varValue;
+    (void)clientData;
 
     if (objc != 2) {
 	Tcl_WrongNumArgs(interp, 1, objv, "name");
@@ -1744,6 +1745,7 @@ ClockClicksObjCmd(
     int index = CLICKS_NATIVE;
     Tcl_Time now;
     Tcl_WideInt clicks = 0;
+    (void)clientData;
 
     switch (objc) {
     case 1:
@@ -1772,8 +1774,7 @@ ClockClicksObjCmd(
 #endif
 	break;
     case CLICKS_MICROS:
-	Tcl_GetTime(&now);
-	clicks = ((Tcl_WideInt) now.sec * 1000000) + now.usec;
+	clicks = TclpGetMicroseconds();
 	break;
     }
 
@@ -1807,6 +1808,7 @@ ClockMillisecondsObjCmd(
     Tcl_Obj *const *objv)	/* Parameter values */
 {
     Tcl_Time now;
+    (void)clientData;
 
     if (objc != 1) {
 	Tcl_WrongNumArgs(interp, 1, objv, NULL);
@@ -1843,15 +1845,12 @@ ClockMicrosecondsObjCmd(
     int objc,			/* Parameter count */
     Tcl_Obj *const *objv)	/* Parameter values */
 {
-    Tcl_Time now;
-
+    (void)clientData;
     if (objc != 1) {
 	Tcl_WrongNumArgs(interp, 1, objv, NULL);
 	return TCL_ERROR;
     }
-    Tcl_GetTime(&now);
-    Tcl_SetObjResult(interp, Tcl_NewWideIntObj(
-	    ((Tcl_WideInt) now.sec * 1000000) + now.usec));
+    Tcl_SetObjResult(interp, Tcl_NewWideIntObj(TclpGetMicroseconds()));
     return TCL_OK;
 }
 
@@ -1999,6 +1998,7 @@ ClockSecondsObjCmd(
     Tcl_Obj *const *objv)	/* Parameter values */
 {
     Tcl_Time now;
+    (void)clientData;
 
     if (objc != 1) {
 	Tcl_WrongNumArgs(interp, 1, objv, NULL);
